@@ -1,5 +1,5 @@
-# Newton's Law of cooling
-# models the cooling of a cup of coffee left in a room
+# Newton's Law of Cooling
+# Models the cooling of a cup of coffee left in a room (ACB)
 # see http://en.wikipedia.org/wiki/Heat_conduction#Newton.27s_law_of_cooling
 require(ddesolve)
 if (!require(PBSmodelling)) stop("The package PBSmodelling must be installed for this demo")
@@ -13,8 +13,7 @@ if (!exists("oldwd") || getwd() != system.file(package = "ddesolve")) {
 	setwd(system.file(package = "ddesolve"))
 }
 
-runPlot <- function()
-{
+runPlot <- function() {
 	#extract variables from window
 	getWinVal(scope="L")
 	
@@ -22,16 +21,13 @@ runPlot <- function()
 	# y[1] represents the tempurature of a cup of coffee at a given time `t'.
 	# dy/dt ~ y - room tempurature. 
 	# so we can write dy/dt = -rho(y - roomTemp)
-	yprime <- function(t, y) {
-	    y1 <- -rho*(y[1]-Tenv)
-	    return(y1)
+	myGrad <- function(t, y) {
+		y1 <- -rho*(y[1]-Tenv)
+		return(y1) 
 	}
-	#we must also specify the initial value or conditions.
-	yinit <- c(Tcup)
-	
 	#solve the ODE from t0..t1 - (ignore hbsize, setting to zero may crash)
-	x <- dde(y=yinit, func=yprime, from=t0, to=t1, hbsize=0) 
-	resetGraph()
+	x <- dde(y=Tcup, func=myGrad, times=seq(t0,t1,length=100), hbsize=0) 
+	frame(); resetGraph();
 	plot(x, type="l", main="Cooling of a cup of coffee", ylab="Tempurature", xlab="Time")
 }
 
